@@ -2,7 +2,7 @@ from typing import Sequence
 
 from libcst import Arg, Call, Name
 
-from django_codemod.constants import DJANGO_20, DJANGO_30
+from django_codemod.constants import DJANGO_2_0, DJANGO_3_0
 from django_codemod.visitors.base import BaseSimpleFuncRenameTransformer
 
 
@@ -14,8 +14,8 @@ class RenderToResponseTransformer(BaseSimpleFuncRenameTransformer):
     ``request=None`` as the first argument of ``render()``.
     """
 
-    deprecated_in = DJANGO_20
-    removed_in = DJANGO_30
+    deprecated_in = DJANGO_2_0
+    removed_in = DJANGO_3_0
     rename_from = "django.shortcuts.render_to_response"
     rename_to = "django.shortcuts.render"
 
